# CustomAttributeModel


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**type** | [**CustomAttributeTypesEnum**](CustomAttributeTypesEnum.md) |  | 
**name** | **str** |  | 
**id** | **str** |  | [optional] 
**options** | [**[CustomAttributeOptionModel], none_type**](CustomAttributeOptionModel.md) |  | [optional] 
**is_deleted** | **bool** |  | [optional] 
**enabled** | **bool** |  | [optional] 
**required** | **bool** |  | [optional] 
**is_global** | **bool** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


